function [C, A, idx] = eig_ny(ny_K)

% computes the exact eigenvalue decomposition of a Nystroem approximated
% matrix
% Input agruments:
%   ny_K is a Nystroem approximated matrix of form
%     ny_K{1}=K_Nm
%     ny_K{2}=K_mm^-1
% Output agruments:
%   C is the matrix of eigenvectors
%   A is the diagonal matrix of eigenvalues

% get eigenvectors of approximated matrix
Temp = ny_K{2}*(ny_K{1}'*ny_K{1})*ny_K{2};
Temp = 0.5 * (Temp+Temp');
[ny_U,ny_A]  = eig(Temp); % normalized cov on landmarks - eigendecomposition on B*B' (da quadrierte matrix wg neg ev
ny_A(ny_A<eps) = 0;
%ny_A = real(ny_A);                        % may happen due to num inst
%ny_U = real(ny_U);
B=ny_K{1}*(ny_U*sqrt(ny_A));     % B = is the left / right part of the K_Nm * K_mm^-1 * K_Nm with inserted decomposition of K_mm^-1 in eigenvalues (U) and eigenvectors (L) 
[V,A] = eig(B'*B);               % eigenvalue decomposition of the covariance matrix of B to get eigenvectors V and eigenvalue matrix A
A(A<eps) = 0;
C=B*(V*sqrt(pinv(A)));           % now we have the eigenvector C of K and actually already the eigenvalue matrix A real(diag(sqrt(A))) - this works for psd matrices

% get eigenvalues of approximated matrix - for non-psd we have a
% to reconstruct the eigenvalues A as follows to avoid the sqrt(-1) issue
% Eigenvalue equation Av = lv
% get eigenvalues by starting with the eigenvectors C of A
% l  = v^-1 * A * v
% l  = (v^-1 * ny_K{1}) * ny_K{2} * ( ny_K{1} *v)
[A,idx]=sort(diag((C'*ny_K{1})*ny_K{2}*(ny_K{1}'*C)),'descend');
A=diag(A);
C=C(:,idx);

end

